<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="taskTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getData"></table-form>
      <!--弹窗 汇报任务-->
      <report-form v-if="showReportVisible" ref="showReport" @refreshData="getData" ></report-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchList, delObj} from '@/api/quality/task'
  import TableForm from './task-form'
  import {mapGetters} from 'vuex'
  import ttable from '@/views/common/ztt-table.vue';
  import ReportForm from "./qualityReport";
  export default {
    data () {
      return {
        ajaxFun:fetchList,
        addOrUpdateVisible: false,
        showReportVisible:false,
        isShowQuery:false,
        multipleSelection: [],
        uploadInfo:{//是否展示上传EXCEL以及对应的url
          isShow:false,
          url:''
        },
        prelang:"operation",
        options: {
          height:300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border:true,//是否有纵向边框
          lazy:false,//是否需要懒加载
          fit:true,//列的宽度是否自撑开
          multiSelect:true,//
          seqNo:true,
          isRefresh:true,//是否显示刷新按钮
          isShowHide:true,//是否显示显影按钮
          isSearch:false,//高级查询按钮
          defaultOrderBy:{column:'createTime',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data:[],
          // 标题
          column: [
            //来源编号
            {minWidth:'120',prop: "sourceNo",label:"来源编号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text',render:{fun:this.addOrUpdateHandle}},
            //来源类型
            {minWidth:'30',prop:"sourceType",label:"来源类型",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',optList:() => {return this.getTestTypeList()}},
            //模板描述
            {minWidth:'140',prop:"templateDesc",label:"模板描述",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //零件号
            {minWidth:'120',prop: "partNo",label:"零件号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //零件名称
            {minWidth:'140',prop:"partName",label:"零件名称",sort: true,isTrue:true,isSearch:true,searchInfoType:'text',},
            //零件批次
            {minWidth:'120',prop: "partBatch",label:"零件批次",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //等待时长
            {minWidth:'120',prop: "createTime",label:"创建时间",sort: true,isTrue:true,isSearch:true,searchInfoType:'datetimerange'},
            ],
          toolbar: [
            {
              text: '新增',
              type: 'primary',
              fun: this.addOrUpdateHandle
            }
          ],
          operator:[
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            },
            {
              text: '汇报',
              type: 'text',
              size: 'small',
              fun: this.showReport
            }
          ],
          operatorConfig:{
            fixed:'right',
            label:'操作',
            width:100,
            minWidth:100
          },
        },
        TestTypeList:[
          {
            value:"采购入库",
            label:'采购入库'
          },
          {
            value:"报工",
            label:'报工'
          },
          {
            value:"巡检",
            label:'巡检'
          }
        ],
      }
    },
    components: {
      ReportForm,
      TableForm,
      ttable,
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getData () {
        this.$refs.taskTable.getDataList();
      },
      // 新增 / 修改
      addOrUpdateHandle (row) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(row==null?null:row.id)
        })
      },
      // 删除
      deleteHandle (row) {
        this.$confirm('是否确认删除零件号为' + row.partNo+'的待检任务', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal:false,
          type: 'warning'
        }).then(function () {
          return delObj(row.id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      },
      showReport(row){
        this.showReportVisible=true
        this.$nextTick(() => {
          this.$refs.showReport.init(row==null?null:row.id)
        })
      },
      handleSelectionChange(val){
        this.multipleSelection = val
      },
      //获取零件来源类型
      getTestTypeList(){
        return this.TestTypeList;
      },
    }
  }
</script>
